/**
 * Copyright 2011 The Kuali Foundation Licensed under the
 * Educational Community License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License. You may
 * obtain a copy of the License at
 *
 * http://www.osedu.org/licenses/ECL-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an "AS IS"
 * BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package org.kuali.common.impex.data;

import java.util.List;

import org.kuali.common.impex.data.service.ExportDataContext;
import org.kuali.common.impex.data.service.ExportDataService;
import org.kuali.common.impex.data.service.impl.ExportTableResult;
import org.kuali.common.impex.model.Schema;
import org.kuali.common.impex.util.ExportUtils;
import org.kuali.common.util.Assert;
import org.kuali.common.util.execute.Executable;

public class DataExportExecutable implements Executable {

	ExportDataContext context;

	ExportDataService service;

    Schema schema;

	Boolean skip;

	public static final Boolean DEFAULT_SKIP_EXECUTION = false;

	@Override
	public void execute() {
        if(skip) {
            return;
        }

        Assert.notNull(schema, "Schema is null");

        List<ExportTableResult> results = service.exportTables(context, schema);

        // after exporting tables, store the table statistics
        ExportUtils.storeTableStatistics(results, context.getTableStatisticsLocation());
	}

	public ExportDataContext getContext() {
		return context;
	}

	public void setContext(ExportDataContext context) {
		this.context = context;
	}

	public ExportDataService getService() {
		return service;
	}

	public void setService(ExportDataService service) {
		this.service = service;
	}

    public Schema getSchema() {
        return schema;
    }

    public void setSchema(Schema schema) {
        this.schema = schema;
    }

    public Boolean getSkip() {
        return skip;
    }

    public void setSkip(Boolean skip) {
        this.skip = skip;
    }
}
